<?php

namespace Drupal\Tests\google_index_api\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests google_index_api bulk update form.
 *
 * @group google_index_api
 */
class GoogleIndexApiBatchTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['google_index_api_dummy_service', 'file'];

  /**
   * {@inheritdoc}
   */
  public $defaultTheme = 'stark';

  /**
   * Use form.
   */
  public function testGoogleIndexApiBulkUpdate() {
    $this->drupalLogin($this->drupalCreateUser(['administer google index api']));

    // Add valid urls.
    $this->drupalGet('/admin/config/services/google-index-api/bulk-update');
    $edit = ['urls' => "https://example.com/some-url\r\nhttps://example.com/something-else"];
    $this->submitForm($edit, 'Submit');

    $this->assertSession()->statusMessageContains('Dummy api call: updated /some-url');
    $this->assertSession()->statusMessageContains('Dummy api call: updated /something-else');

    // Add invalid urls. Relative urls or urls sans-http(s) are invalid.
    $this->drupalGet('/admin/config/services/google-index-api/bulk-update');
    $edit = ['urls' => "/not-a-url\r\nwww.example.com/something-else"];
    $this->submitForm($edit, 'Submit');

    $this->assertSession()->statusMessageContains('No Valid URLs to Process!', 'warning');

    // Try a valid file.
    file_put_contents("public://test.txt", "https://example.com/some-url-in-file\r\nhttps://example.com/something-else-in-file");
    $this->drupalGet('/admin/config/services/google-index-api/bulk-update');
    $page = $this->getSession()->getPage();
    $page->checkField('upload');
    $page->attachFileToField('files[uploadz]', $this->container->get('file_system')->realpath("public://test.txt"));
    $this->submitForm([], 'Submit');

    $this->assertSession()->statusMessageContains('Dummy api call: updated /some-url-in-file');
    $this->assertSession()->statusMessageContains('Dummy api call: updated /something-else-in-file');
  }

}
